@@ -9,23 +9,24 @@
 #' doi: 10.1080/15481603.2020.1760434.
 #'
 #' @param formula A formula of OPGD model.
-#' @param data A data.frame, tibble or sf object of observation data.
+#' @param data A `data.frame`, `tibble` or `sf` object of observation data.
 #' @param discvar Name of continuous variable columns that need to be discretized. Noted that
 #' when `formula` has `discvar`, `data` must have these columns. By default, all independent
 #' variables are used as `discvar`.
-#' @param discnum (optional) A vector of number of classes for discretization. Default is `3:22`.
+#' @param discnum (optional) A vector of number of classes for discretization. Default is `3:8`.
 #' @param discmethod (optional) A vector of methods for discretization, default is using
 #' `c("sd","equal","geometric","quantile","natural")` by invoking `sdsfun`.
 #' @param cores (optional) Positive integer (default is 1). When cores are greater than 1, use
 #' multi-core parallel computing.
-#' @param type (optional) The type of geographical detector,which must be `factor`(default),
+#' @param type (optional) The type of geographical detector, which must be `factor`(default),
 #' `interaction`, `risk`, `ecological`. You can run one or more types at one time.
-#' @param alpha (optional) Specifies the size of confidence level.Default is `0.95`.
+#' @param alpha (optional) Specifies the size of confidence level. Default is `0.95`.
 #' @param ... (optional) Other arguments passed to `gd_bestunidisc()`. A useful parameter is `seed`,
 #'  which is used to set the random number seed.
 #'
 #' @return A list.
 #' \describe{
+#' \item{\code{opt_param}}{optimal discretization parameter}
 #' \item{\code{factor}}{the result of factor detector}
 #' \item{\code{interaction}}{the result of interaction detector}
 #' \item{\code{risk}}{the result of risk detector}
@@ -39,12 +40,13 @@
 #'      discvar = paste0('x',letters[1:3]),
 #'      discnum = 3:6)
 #'
-opgd = \(formula, data, discvar = NULL, discnum = 3:22,
+opgd = \(formula, data, discvar = NULL, discnum = 3:8,
          discmethod = c("sd","equal","geometric","quantile","natural"),
          cores = 1, type = "factor", alpha = 0.95, ...){
   formula = stats::as.formula(formula)
   formula.vars = all.vars(formula)
   if (inherits(data,'sf')) {data = sf::st_drop_geometry(data)}
+  data = tibble::as_tibble(data)
   if (formula.vars[2] != "."){
     data = dplyr::select(data,dplyr::all_of(formula.vars))
   }
@@ -52,10 +54,12 @@ opgd = \(formula, data, discvar = NULL, discnum = 3:22,
   if (is.null(discvar)) {
     discvar = colnames(data)[-which(colnames(data) == yname)]
   }
-  discdf =  dplyr::select(data,dplyr::all_of(c(yname,discvar)))
+  discdf = dplyr::select(data,dplyr::all_of(c(yname,discvar)))
   g = gd_bestunidisc(paste0(yname,'~',paste0(discvar,collapse = '+')),
                      data = discdf, discnum = discnum,
                      discmethod = discmethod, cores = cores, ...)
+  opt_param = tibble::as_tibble(g[1:3])
+  names(opt_param) = c("varibale","discnum","method")
   discedvar = colnames(data[,-which(colnames(data) %in% discvar)])
   newdata = data %>%
     dplyr::select(dplyr::all_of(discedvar)) %>%
@@ -70,6 +74,7 @@ opgd = \(formula, data, discvar = NULL, discnum = 3:22,
     }
     names(res) = type
   }
+  res = append(list("opt_param" = opt_param),res)
   class(res) = "opgd_result"
   return(res)
 }
@@ -83,10 +88,10 @@ opgd = \(formula, data, discvar = NULL, discnum = 3:22,
 #' @param ... (optional) Other arguments passed to `knitr::kable()`.
 #'
 #' @return Formatted string output
-#' @method print opgd_result
 #' @export
 #'
 print.opgd_result = \(x, ...) {
+  x = x[-1] # rm opt_param to print
   cat("                OPGD Model                  \n")
   nx = names(x)
   for (i in seq_along(x)){
@@ -106,10 +111,10 @@ print.opgd_result = \(x, ...) {
 #' @param ... (optional) Other arguments passed to `patchwork::wrap_plots()`.
 #'
 #' @return A ggplot2 layer
-#' @method plot opgd_result
 #' @export
 #'
 plot.opgd_result = \(x, ...) {
+  x = x[-1] # rm opt_param to plot
   if (length(x) == 1){
     res = x[1]
     nx = names(x)
