@@ -8,12 +8,12 @@
 #' Journal of Geographical Information Science, 32:10, 2055-2075, DOI:  10.1080/13658816.2018.1476693
 #'
 #' @param formula A formula of spatial association detector (SPADE) model.
-#' @param data A data.frame, tibble or sf object of observation data.
+#' @param data A `data.frame`, `tibble` or `sf` object of observation data.
 #' @param wt (optional) The spatial weight matrix. When `data` is not an `sf` object, must provide `wt`.
 #' @param discvar (optional) Name of continuous variable columns that need to be discretized. Noted that
 #' when `formula` has `discvar`, `data` must have these columns. By default, all independent variables are
 #' used as `discvar`.
-#' @param discnum (optional) Number of multilevel discretization. Default will use `3:22`.
+#' @param discnum (optional) Number of multilevel discretization. Default will use `3:8`.
 #' @param discmethod (optional) The discretization methods. Default all use `quantile`. Note
 #' that when using different `discmethod` for `discvar`, please ensure that the lengths of
 #' both are consistent. Noted that `robust` will use `robust_disc()`; `rpart` will use
@@ -38,7 +38,7 @@
 #' g = spade(y ~ ., data = sim1)
 #' g
 #'
-spade = \(formula, data, wt = NULL, discvar = NULL, discnum = 3:22,
+spade = \(formula, data, wt = NULL, discvar = NULL, discnum = 3:8,
           discmethod = 'quantile', cores = 1, seed = 123456789, permutations = 0, ...){
   formula = stats::as.formula(formula)
   formula.vars = all.vars(formula)
@@ -56,6 +56,7 @@ spade = \(formula, data, wt = NULL, discvar = NULL, discnum = 3:22,
       wt_spade = wt
     }
   }
+  data = tibble::as_tibble(data)
   if (formula.vars[2] != "."){
     data = dplyr::select(data,dplyr::all_of(formula.vars))
   }
@@ -107,7 +108,6 @@ spade = \(formula, data, wt = NULL, discvar = NULL, discnum = 3:22,
 #' @param ... Other arguments.
 #'
 #' @return Formatted string output
-#' @method print spade_result
 #' @export
 print.spade_result = \(x, ...) {
   cat("***         Spatial Association Detector         ")
@@ -129,7 +129,6 @@ print.spade_result = \(x, ...) {
 #' @param ... (optional) Other arguments passed to `ggplot2::theme()`.
 #'
 #' @return A ggplot2 layer.
-#' @method plot spade_result
 #' @export
 #'
 plot.spade_result = \(x, slicenum = 2, alpha = 0.95, keep = TRUE, ...) {
